@@ -2,13 +2,7 @@ import logging
 
 
 def init_logger(name, testing_mode) -> logging.Logger:
-    log_format = (
-        "%(asctime)s - "
-        "%(name)s - "
-        "%(funcName)s - "
-        "%(levelname)s - "
-        "%(message)s"
-    )
+    log_format = "%(asctime)s - " "%(name)s - " "%(funcName)s - " "%(levelname)s - " "%(message)s"
     logging.basicConfig(format=log_format)
     logger = logging.getLogger(name)
 
